Crate fieldx_derive_support

Crate fieldx_derive_support 

This crate provides automations to simplify development of the fieldx_aux and fieldx_derive crates.

Macros

fallback_prop

Attribute Macros

fxhelper
This macro is used to generate helper structs. It adds the following fields to support related helper functionality: